import uuid
import random
import pytest
from sqlalchemy import create_engine
from sqlalchemy.sql import text as sa_text
from sqlalchemy.orm import sessionmaker
from opencdms.models import surface
from config import get_surface_connection_string

DB_URL = get_surface_connection_string()

db_engine = create_engine(DB_URL)

station_data = {
    "id": 999999,
    "created_at": "2015-01-21T17:01:29.000Z",
    "updated_at": "2022-07-08T15:38:16.894Z",
    "name": "PGIA",
    "alias_name": "PGIA CR1000",
    "begin_date": "2014-10-01T00:00:00.000Z",
    "end_date": None,
    "longitude": -88.3127,
    "latitude": 17.5348,
    "elevation": 5.0,
    "code": "9958303",
    "wmo": None,
    "wigos": None,
    "is_active": True,
    "is_automatic": True,
    "organization": None,
    "observer": None,
    "watershed": "Belize River",
    "z": None,
    "datum": None,
    "zone": None,
    "ground_water_province": None,
    "river_code": None,
    "river_course": None,
    "catchment_area_station": None,
    "river_origin": None,
    "easting": None,
    "northing": None,
    "river_outlet": None,
    "river_length": None,
    "local_land_use": None,
    "soil_type": None,
    "site_description": None,
    "land_surface_elevation": None,
    "screen_length": None,
    "top_casing_land_surface": None,
    "depth_midpoint": None,
    "screen_size": None,
    "casing_type": None,
    "casing_diameter": None,
    "existing_gauges": None,
    "flow_direction_at_station": None,
    "flow_direction_above_station": None,
    "flow_direction_below_station": None,
    "bank_full_stage": None,
    "bridge_level": None,
    "access_point": None,
    "temporary_benchmark": None,
    "mean_sea_level": None,
    "data_type": None,
    "frequency_observation": None,
    "historic_events": None,
    "other_information": None,
    "hydrology_station_type": None,
    "is_surface": False,
    "station_details": None,
    "remarks": "Belize",
    "region": "Belize",
    "utc_offset_minutes": -360,
    "alternative_names": None,
    "wmo_station_plataform": None,
    "operation_status": True,
    "communication_type_id": 4,
    "data_source_id": 1,
    "profile_id": 4,
    "wmo_program_id": None,
    "wmo_region_id": None,
    "wmo_station_type_id": None,
    "relocation_date": None,
    "network": None,
    "reference_station_id": None,
    "country_id": 18,
}

station_communication_data = {
    "id": 4,
    "created_at": "2019-11-27T18:29:46.352Z",
    "updated_at": "2019-11-29T20:54:28.776Z",
    "name": "RF",
    "description": "RF Link",
    "color": "#01A27F",
}

data_source_data = {
    "id": 1,
    "created_at": "2019-01-09T13:58:55.345Z",
    "updated_at": "2019-04-26T20:31:52.335Z",
    "symbol": "NMS",
    "name": "NMS",
    "base_url": "http:\/\/www.hydromet.gov.bz",
    "location": None,
}

station_profile_data = {
    "id": 4,
    "created_at": "2016-04-01T01:58:36.000Z",
    "updated_at": "2020-05-22T22:39:27.835Z",
    "name": "Aviation",
    "description": "Weather station measuring parameters supporting aviation",
    "color": "#f9f008",
    "is_automatic": True,
    "is_manual": True,
}

country_data = {
    "id": 18,
    "created_at": "2015-01-21T17:01:28.000Z",
    "updated_at": "2022-04-13T15:24:34.390Z",
    "notation": "BLZ",
    "name": "Belize",
    "description": "Belize",
}


@pytest.fixture
def db_session():
    Session = sessionmaker(bind=db_engine)
    session = Session()
    yield session
    session.close()


def setup_module(module):
    # Postgresql does not automatically reset ID if a table is truncated like mysql does
    with db_engine.connect() as connection:
        with connection.begin():
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxCountry.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStationprofile.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxDatasource.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStationcommunication.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStation.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )

    Session = sessionmaker(bind=db_engine)
    session = Session()

    session.add(surface.WxCountry(**country_data))
    session.add(surface.WxDatasource(**data_source_data))
    session.add(surface.WxStationcommunication(**station_communication_data))
    session.add(surface.WxStationprofile(**station_profile_data))

    session.commit()
    session.close()


def teardown_module(module):
    # Postgresql does not automatically reset ID if a table is truncated like mysql does
    with db_engine.connect() as connection:
        with connection.begin():
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxCountry.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStationprofile.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxDatasource.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStationcommunication.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {surface.WxStation.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )


@pytest.mark.order(500)
def test_should_create_a_station(db_session):
    station = surface.WxStation(**station_data)
    db_session.add(station)
    db_session.commit()

    assert station.id == station_data["id"]


@pytest.mark.order(501)
def test_should_read_all_stations(db_session):
    stations = db_session.query(surface.WxStation).all()

    for station in stations:
        assert isinstance(station, surface.WxStation)


@pytest.mark.order(502)
def test_should_return_a_single_station(db_session):
    station = db_session.query(surface.WxStation).get(station_data["id"])

    assert station.id == station_data["id"]


@pytest.mark.order(503)
def test_should_update_station(db_session):
    db_session.query(surface.WxStation).filter_by(id=station_data["id"]).update(
        {"region": "US"}
    )
    db_session.commit()

    updated_station = db_session.query(surface.WxStation).get(station_data["id"])

    assert updated_station.region == "US"


@pytest.mark.order(504)
def test_should_delete_station(db_session):
    db_session.query(surface.WxStation).filter_by(id=station_data["id"]).delete()
    db_session.commit()

    deleted_station = db_session.query(surface.WxStation).get(station_data["id"])

    assert deleted_station is None



import os

from dotenv import load_dotenv

load_dotenv()


def get_connection_string(engine: str, driver: str, user: str, password: str, host: str, port: str, db_name: str) -> str:
    return f"{engine}+{driver}://{user}:{password}@{host}:{port}/{db_name}"


def get_clide_connection_string() -> str:
    return get_connection_string(
        engine="postgresql",
        driver="psycopg2",
        user="postgres",
        password="password",
        host="127.0.0.1",
        port=os.getenv("CLIDE_PORT"),
        db_name=os.getenv("CLIDE_DB_NAME")
    )


def get_climsoft_4_1_1_connection_string() -> str:
    return get_connection_string(
        engine="mysql",
        driver="mysqldb",
        user="root",
        password="password",
        host="127.0.0.1",
        port=os.getenv("CLIMSOFT_4_1_1_PORT"),
        db_name=os.getenv("CLIMSOFT_DB_NAME")
    )


def get_mch_english_connection_string(port_override: str = None) -> str:
    return get_connection_string(
        engine="mysql",
        driver="mysqldb",
        user="root",
        password="password",
        host="127.0.0.1",
        port=os.getenv("MCH_ENGLISH_PORT") if port_override is None else port_override,
        db_name=os.getenv("MCH_DB_NAME")
    )


def get_midas_connection_string(port_override: str = None) -> str:
    return get_connection_string(
        engine="postgresql",
        driver="psycopg2",
        user="postgres",
        password="password",
        host="127.0.0.1",
        port=os.getenv("MIDAS_PORT") if port_override is None else port_override,
        db_name=os.getenv("MIDAS_DB_NAME")
    )


def get_surface_connection_string(port_override: str = None) -> str:
    return get_connection_string(
        engine="postgresql",
        driver="psycopg2",
        user="postgres",
        password="password",
        host="127.0.0.1",
        port=os.getenv("SURFACE_PORT", 45432) if port_override is None else port_override,
        db_name=os.getenv("SURFACE_DB_NAME", "postgres")
    )




import os
import pandas
import pytest
import datetime
from opencdms import MidasPgOpen


BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
DB_URL = os.path.join(BASE_DIR, "opencdms_test_data", "data")


@pytest.fixture
def session():
    return MidasPgOpen(connection_string=DB_URL)


def test_should_return_hourly_wind_obs(session):
    filters = {
        "src_id": 838,
        "period": "hourly",
        "year": 1991,
        "elements": ["wind_speed", "wind_direction"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)

    assert (
        datetime.datetime.strptime(obs.iloc[1]["ob_time"], "%Y-%m-%d %H:%M:%S")
        - datetime.datetime.strptime(
            obs.iloc[0]["ob_time"], "%Y-%m-%d %H:%M:%S"
        )
    ).total_seconds() == 3600


def test_should_return_hourly_rain_prcp_amt_obs(session):
    filters = {
        "src_id": 838,
        "period": "hourly",
        "year": 1991,
        "elements": ["prcp_amt"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)

    assert (
        datetime.datetime.strptime(
            obs.iloc[1]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
        - datetime.datetime.strptime(
            obs.iloc[0]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
    ).total_seconds() == 3600


def test_should_return_daily_rain_prcp_amt_obs(session):

    filters = {
        "src_id": 838,
        "period": "daily",
        "year": 1991,
        "elements": ["prcp_amt"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)
    assert (
        datetime.datetime.strptime(obs.iloc[2]["ob_date"], "%Y-%m-%d %H:%M:%S")
        - datetime.datetime.strptime(
            obs.iloc[1]["ob_date"], "%Y-%m-%d %H:%M:%S"
        )
    ).days == 1


def test_should_return_daily_temperature_obs(session):
    filters = {
        "src_id": 838,
        "period": "daily",
        "year": 1991,
        "elements": ["max_air_temp", "min_air_temp"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)

    assert (
        datetime.datetime.strptime(
            obs.iloc[2]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
        - datetime.datetime.strptime(
            obs.iloc[1]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
    ).days == 1


def test_should_return_daily_radiation_obs(session):
    filters = {
        "src_id": 838,
        "period": "daily",
        "year": 1991,
        "elements": ["glbl_irad_amt", "difu_irad_amt"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)

    assert (
        datetime.datetime.strptime(
            obs.iloc[2]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
        - datetime.datetime.strptime(
            obs.iloc[1]["ob_end_time"], "%Y-%m-%d %H:%M:%S"
        )
    ).total_seconds() == 3600


def test_should_return_daily_soil_temperature_obs(session):
    filters = {
        "src_id": 838,
        "period": "daily",
        "year": 1991,
        "elements": ["q5cm_soil_temp", "q10cm_soil_temp"],
    }

    obs = session.obs(**filters)

    assert isinstance(obs, pandas.DataFrame)

    assert (
        datetime.datetime.strptime(obs.iloc[2]["ob_time"], "%Y-%m-%d %H:%M:%S")
        - datetime.datetime.strptime(
            obs.iloc[1]["ob_time"], "%Y-%m-%d %H:%M:%S"
        )
    ).days == 1



import random
import pytest
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from opencdms.models.climsoft import v4_1_1_core as climsoft
from config import get_climsoft_4_1_1_connection_string

DB_URL = get_climsoft_4_1_1_connection_string()

db_engine = create_engine(DB_URL)

station_data = dict(
    stationId=str(random.randint(1000, 2000)),
    stationName="Test Station",
    country="UK",
)


@pytest.fixture
def db_session():
    Session = sessionmaker(bind=db_engine)
    session = Session()
    yield session
    session.close()


def setup_module(module):
    with db_engine.connect() as connection:
        trans = connection.begin()
        connection.execute("SET FOREIGN_KEY_CHECKS = 0;")
        for table in climsoft.metadata.sorted_tables:
            connection.execute(table.delete())
        connection.execute("SET FOREIGN_KEY_CHECKS = 1;")
        trans.commit()


def teardown_module(module):
    with db_engine.connect() as connection:
        trans = connection.begin()
        connection.execute("SET FOREIGN_KEY_CHECKS = 0;")
        for table in climsoft.metadata.sorted_tables:
            connection.execute(table.delete())
        connection.execute("SET FOREIGN_KEY_CHECKS = 1;")
        trans.commit()


@pytest.mark.order(200)
def test_should_create_a_station(db_session):
    station = climsoft.Station(**station_data)
    db_session.add(station)
    db_session.commit()

    assert station.stationId == station_data["stationId"]


@pytest.mark.order(201)
def test_should_read_all_stations(db_session):
    stations = db_session.query(climsoft.Station).all()

    for station in stations:
        assert isinstance(station, climsoft.Station)


@pytest.mark.order(202)
def test_should_return_a_single_station(db_session):
    station = db_session.query(climsoft.Station).get(station_data["stationId"])

    assert station.stationId == station_data["stationId"]


@pytest.mark.order(203)
def test_should_update_station(db_session):
    db_session.query(climsoft.Station).filter_by(
        stationId=station_data["stationId"]
    ).update({"country": "US"})
    db_session.commit()

    updated_station = db_session.query(climsoft.Station).get(
        station_data["stationId"]
    )

    assert updated_station.country == "US"


@pytest.mark.order(204)
def test_should_delete_station(db_session):
    db_session.query(climsoft.Station).filter_by(
        stationId=station_data["stationId"]
    ).delete()
    db_session.commit()

    deleted_station = db_session.query(climsoft.Station).get(
        station_data["stationId"]
    )

    assert deleted_station is None



"""Console script for opencdms."""
import sys
import click
import subprocess
from pathlib import Path
import socket

def _check_port(port)->bool:
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
        return s.connect_ex(('localhost', port)) == 0


@click.group()
def main(args=None):
    """Console script for opencdms-test-data."""
    # See click documentation at https://click.palletsprojects.com/
    pass

@click.command(name="startdb")
@click.option('--containers', help='Comma separated list of container(s) to be started')
def start_db(containers: str):
    """ 
       Starts Database containers
    
    
     """
    container_port = {
        "postgres": 5432,
        "mariadb": 3306,
        "opencdmsdb": 35432,
        "postgresql": 25432,
        "mysql": 23306,
        "oracle": 21521,
        "clide": 35433,
        "climsoft-4.1.1": 33308,
        "mch-english": 33306,
        "midas": 31521,        
        "wmdr": 35434,
        "surface": 45432

    }
    

    docker_compose_file = f"{Path(__file__).parent}/docker-compose.yml"
    if containers is None:
        # Start all contianers
        service_ports = container_port.values()
        occupied = False
        for port in service_ports:
            if _check_port(port):
                click.echo(f"########### Port {port} is in use by another service. Close the service and run again. #############")
                occupied = True
        if occupied and not click.confirm("Some ports are already in use by another service. Do you want to continue ?"):
            exit(0)
        start_command = f"docker-compose -f {docker_compose_file} up -d"
        containers_started = container_port.keys()
    else:
        containers_to_start = containers.split(",")
        containers_started = []
        for container in containers_to_start:
            if container in container_port.keys():
                if _check_port(container_port[container]) is True:
                    click.echo(f"########### Service Port {container_port[container]} for {container} is in use by another service. #############")
                    continue
            else:
                click.echo(f"########### Invalid container name {container} #############")
                continue            
            containers_started.append(container)
        if len(containers_started) > 0:
            databases = " ".join(containers_started)
            start_command = f"docker-compose -f {docker_compose_file} up -d {databases}"
        else:
            exit(0)
    
    
    click.echo('starting databases....')
    out = subprocess.run(start_command,shell=True)
    if out.returncode != 0:
        click.echo("Start up not successfull")
        click.echo(out.stderr)
        click.echo("please close any conflicting ports")
    else:
        click.echo(out.stdout)
    click.echo("To stop running databases run: opencdms-test-data stopdb")
    return out.returncode

@click.command(name="stopdb")
def stop_db():
    """ Stops all database containers """
    docker_compose_file = f"{Path(__file__).parent}/docker-compose.yml"
    click.echo(docker_compose_file)
    out = subprocess.run(f"docker-compose -f {docker_compose_file} down", shell=True)

main.add_command(start_db)
main.add_command(stop_db)

if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



import os

import pytest
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from opencdms.models.mch import english as mch_english
from config import get_mch_english_connection_string

DB_URL = get_mch_english_connection_string(
    port_override=os.getenv("MCH_ENGLISH_PORT")
)

db_engine = create_engine(DB_URL)

station_data = dict(Station="TEST", StationName="Test Station")


@pytest.fixture
def db_session():
    Session = sessionmaker(bind=db_engine)
    session = Session()
    yield session
    session.close()


def setup_module(module):
    with db_engine.connect() as connection:
        trans = connection.begin()
        connection.execute("SET FOREIGN_KEY_CHECKS = 0;")
        for table in mch_english.metadata.sorted_tables:
            connection.execute(table.delete())
        connection.execute("SET FOREIGN_KEY_CHECKS = 1;")
        trans.commit()


def teardown_module(module):
    with db_engine.connect() as connection:
        trans = connection.begin()
        connection.execute("SET FOREIGN_KEY_CHECKS = 0;")
        for table in mch_english.metadata.sorted_tables:
            connection.execute(table.delete())
        connection.execute("SET FOREIGN_KEY_CHECKS = 1;")
        trans.commit()


@pytest.mark.order(400)
def test_should_create_a_station(db_session):
    station = mch_english.Station(**station_data)
    db_session.add(station)
    db_session.commit()

    assert station.Station == station_data["Station"]


@pytest.mark.order(401)
def test_should_read_all_stations(db_session):
    stations = db_session.query(mch_english.Station).all()

    for station in stations:
        assert isinstance(station, mch_english.Station)


@pytest.mark.order(402)
def test_should_return_a_single_station(db_session):
    station = db_session.query(mch_english.Station).get(
        station_data["Station"]
    )

    assert station.Station == station_data["Station"]


@pytest.mark.order(403)
def test_should_update_station(db_session):
    db_session.query(mch_english.Station).filter_by(
        Station=station_data["Station"]
    ).update({"StationName": "Updated Station Name"})
    db_session.commit()

    updated_station = db_session.query(mch_english.Station).get(
        station_data["Station"]
    )

    assert updated_station.StationName == "Updated Station Name"


@pytest.mark.order(404)
def test_should_delete_station(db_session):
    db_session.query(mch_english.Station).filter_by(
        Station=station_data["Station"]
    ).delete()
    db_session.commit()

    deleted_station = db_session.query(mch_english.Station).get(
        station_data["Station"]
    )

    assert deleted_station is None



import uuid
import random
import pytest
from sqlalchemy import create_engine
from sqlalchemy.sql import text as sa_text
from sqlalchemy.orm import sessionmaker
from opencdms.models import clide
from config import get_clide_connection_string

DB_URL = get_clide_connection_string()


db_engine = create_engine(DB_URL)

station_status_data = dict(
    id=1, status="ACTIVE", description="test station status 1"
)

timezone_data = dict(
    id=1, tm_zone="UTC", utc_diff=0, description="UTC timezone"
)

station_data = dict(
    id=random.randint(1000, 2000),
    station_no=uuid.uuid4().hex[:15],
    status_id=station_status_data["id"],
    time_zone=timezone_data["tm_zone"],
    region="UK",
)


@pytest.fixture
def db_session():
    Session = sessionmaker(bind=db_engine)
    session = Session()
    yield session
    session.close()


def setup_module(module):
    # Postgresql does not automatically reset ID if a table is truncated like mysql does
    with db_engine.connect() as connection:
        with connection.begin():
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.Station.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.StationStatu.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.StationTimezone.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )

    Session = sessionmaker(bind=db_engine)
    session = Session()

    session.add(clide.StationStatu(**station_status_data))
    session.add(clide.StationTimezone(**timezone_data))

    session.commit()
    session.close()


def teardown_module(module):
    # Postgresql does not automatically reset ID if a table is truncated like mysql does
    with db_engine.connect() as connection:
        with connection.begin():
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.Station.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.StationStatu.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )
            db_engine.execute(
                sa_text(
                    f"""TRUNCATE TABLE {clide.StationTimezone.__tablename__} RESTART IDENTITY CASCADE"""
                ).execution_options(autocommit=True)
            )


@pytest.mark.order(100)
def test_should_create_a_station(db_session):
    station = clide.Station(**station_data)
    db_session.add(station)
    db_session.commit()

    assert station.id == station_data["id"]


@pytest.mark.order(101)
def test_should_read_all_stations(db_session):
    stations = db_session.query(clide.Station).all()

    for station in stations:
        assert isinstance(station, clide.Station)


@pytest.mark.order(102)
def test_should_return_a_single_station(db_session):
    station = db_session.query(clide.Station).get(station_data["id"])

    assert station.id == station_data["id"]


@pytest.mark.order(103)
def test_should_update_station(db_session):
    db_session.query(clide.Station).filter_by(id=station_data["id"]).update(
        {"region": "US"}
    )
    db_session.commit()

    updated_station = db_session.query(clide.Station).get(station_data["id"])

    assert updated_station.region == "US"


@pytest.mark.order(104)
def test_should_delete_station(db_session):
    db_session.query(clide.Station).filter_by(id=station_data["id"]).delete()
    db_session.commit()

    deleted_station = db_session.query(clide.Station).get(station_data["id"])

    assert deleted_station is None



#!/usr/bin/env python
from setuptools import setup

with open("README.md") as readme_file:
    readme = readme_file.read()

setup(
    name='opencdms_test_databases',
    version="0.1.10",
    description='OpenCDMS test databases',
    license="MIT license",
    long_description=readme + "\n",
    long_description_content_type='text/markdown',
    author='OpenCDMS',
    author_email='info@opencdms.org',
    maintainer='Ian Edwards',
    maintainer_email='info@opencdms.org',
    url='https://github.com/opencdms/opencdms-test-databases',
    keywords="opencdms",
    packages=['opencdms_test_databases'],
    include_package_data=True,
    zip_safe=False,
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
